# Program : run_heigen.sh
# Description : Run HEigen (Hadoop EIgensolver)

which hadoop > /dev/null
status=$?
if test $status -ne 0 ; then
	echo ""
	echo "Hadoop is not installed in the system."
	echo "Please install Hadoop and make sure the hadoop binary is accessible."
	exit 127
fi

if [ $# -ne 4 ]; then
	 echo 1>&2 Usage: $0 [#_of_nodes] [#_of_reducers] [HDFS edge_file_path] [makesym or nosym]
	 echo 1>&2 [#_of_nodes] : number of nodes in the graph
	 echo 1>&2 [#_of_reducers] : number of reducers to use in hadoop
	 echo 1>&2 [HDFS edge_file_path] : HDFS directory where edge file is located
	 echo 1>&2 [makesym or nosym] : makesym-duplicate reverse edges, nosym-use original edge file
	 echo 1>&2    ex: $0 6 3 lz_edge makesym
	 exit 127
fi


hadoop jar heigen-0.9.jar pegasus.HEigen $3 lz_q1 $1 $2 $4 20 1 LM 6 1
iteration=`wc -l lanczos.ab | cut -f 1 -d ' '`
./run_qtoritz.sh $iteration $2 q_matrix null
./run_ritz_cimv.sh $iteration 6 $2 LM q_matrix

echo ""
echo "HEigen finished. Here are top 6 eigenvalues:"
cat ritz.map
echo ""
echo "The eigenvectors are saved in HDFS rz_v1 to rz_v6."
